==> karot_components-0.0.1.tar.gz: lib/constant/theme.dart <==
// ignore_for_file: constant_identifier_names

import 'package:flutter/material.dart';

class KRTheme {
  KRTheme._();
  static const DEFAULT_LIGHT_COLOR = 0xFFFFFFFF;
  static const DEFAULT_DARK_COLOR = 0xFF000000;
  static const DEFAULT_GREY_COLOR = 0xFF393939;

  static const DEFAULT_PRIMARY_COLOR = 0xFFE91A4D;
  static const DEFAULT_PRIMARY_LIGHT_COLOR = 0xFFE73763;
  static const DEFAULT_PRIMARY_OVERLAY_COLOR = 0x41D6375F;
  static const DEFAULT_SECONDARY_COLOR = 0xFFDFD25B;

  static const SMALL_BTN_FONT_SIZE = 12.0;
  static const REGULAR_BTN_FONT_SIZE = 14.0;
  static const LARGE_BTN_FONT_SIZE = 18.0;

  static const CAPTION_TEXT_FONT_SIZE = 12.0;
  static const BODY_TEXT_FONT_SIZE = 14.0;
  static const SUBTITLE_TEXT_FONT_SIZE = 18.0;
  static const TITLE_TEXT_FONT_SIZE = 24.0;
  static const HEADLINE_TEXT_FONT_SIZE = 32.0;

  static const double PADDING = 10;
  static const double DIALOG_MARGIN_FROM_SCREEN = 20;

  static const double SPACE_BETWEEN_COMPONENT = 10;
}

class KRColor extends MaterialStateColor {
  final int defaultColor;
  final int pressedColor;

  const KRColor(
      {this.defaultColor = KRTheme.DEFAULT_PRIMARY_COLOR,
      this.pressedColor = KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR})
      : super(d);

  static const int d = KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR;

  @override
  Color resolve(Set<MaterialState> states) {
    if (states.contains(MaterialState.pressed)) {
      return Color(defaultColor);
    }

    if (states.contains(MaterialState.disabled)) {
      return Color(pressedColor);
    }

    if (states.contains(MaterialState.hovered)) {
      return Color(pressedColor);
    }

    return Color(defaultColor);
  }
}

==> karot_components-0.0.2.tar.gz: lib/constant/theme.dart <==
// ignore_for_file: constant_identifier_names

import 'package:flutter/material.dart';

class KRTheme {
  KRTheme._();

  static const DEFAULT_CLEAR_COLOR = 0x00FFFFFF;

  static const DEFAULT_LIGHT_COLOR = 0xFFFFFFFF;
  static const DEFAULT_DARK_COLOR = 0xFF000000;
  static const DEFAULT_GREY_COLOR = 0xFF5D5D5D;

  static const DEFAULT_PRIMARY_COLOR = 0xFFd02c2f;
  static const DEFAULT_PRIMARY_LIGHT_COLOR = 0xFFF1DCDD;
  static const DEFAULT_PRIMARY_OVERLAY_COLOR = 0xA9CCAAB1;
  static const DEFAULT_SECONDARY_COLOR = 0xFFEEECC8;
  static const DEFAULT_THIRD_COLOR = 0xFFB7EDA3;

  static const DEFAULT_TERTIARY_COLOR = 0xFFDEEEDC;
  static const DEFAULT_TERTIARY_LIGHT_COLOR = 0xFFF0EFDD;
  



  static const SMALL_BTN_FONT_SIZE = 12.0;
  static const REGULAR_BTN_FONT_SIZE = 14.0;
  static const LARGE_BTN_FONT_SIZE = 18.0;

  static const CAPTION_TEXT_FONT_SIZE = 12.0;
  static const BODY_TEXT_FONT_SIZE = 14.0;
  static const SUBTITLE_TEXT_FONT_SIZE = 18.0;
  static const TITLE_TEXT_FONT_SIZE = 24.0;
  static const HEADLINE_TEXT_FONT_SIZE = 32.0;

  static const double PADDING_LARGE = 15;
  static const double PADDING_NORMAL = 10;
  static const double PADDING_SMALL = 5;
  static const double DIALOG_MARGIN_FROM_SCREEN = 20;

  static const double SPACE_BETWEEN_COMPONENT = 10;
}

class KRColor extends MaterialStateColor {
  final int defaultColor;
  final int pressedColor;

  const KRColor(
      {this.defaultColor = KRTheme.DEFAULT_PRIMARY_COLOR,
      this.pressedColor = KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR})
      : super(d);

  static const int d = KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR;

  @override
  Color resolve(Set<MaterialState> states) {
    if (states.contains(MaterialState.pressed)) {
      return Color(defaultColor);
    }

    if (states.contains(MaterialState.disabled)) {
      return Color(pressedColor);
    }

    if (states.contains(MaterialState.hovered)) {
      return Color(pressedColor);
    }

    return Color(defaultColor);
  }
}
